<?php

namespace Drupal\purge_purger_keycdn\Plugin\Purge\DiagnosticCheck;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\purge\Plugin\Purge\DiagnosticCheck\DiagnosticCheckBase;
use Drupal\purge\Plugin\Purge\DiagnosticCheck\DiagnosticCheckInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Verifies that only fully configured Key CDN purgers load.
 *
 * @PurgeDiagnosticCheck(
 *   id = "purge_purger_keycdn",
 *   title = @Translation("Key CDN "),
 *   description = @Translation("Tests your Key CDN configuration."),
 * )
 */
class ConfigurationCheck extends DiagnosticCheckBase implements DiagnosticCheckInterface {

  /**
   * The config object.
   *
   * \Drupal\Core\Config\ImmutableConfig;
   */
  protected $config;

  /**
   * Constructs an instance of ConfigurationCheck.
   *
   * @param array $configuration
   *   A configuration array containing information about the plugin instance.
   * @param string $plugin_id
   *   The plugin_id for the plugin instance.
   * @param mixed $plugin_definition
   *   The plugin implementation definition.
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config
   *   The config object.
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, ConfigFactoryInterface $config) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->config = $config->get('purge_purger_keycdn.settings');
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('config.factory')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function run() {
    if (empty($this->config->get("api_key"))) {
      $this->recommendation = $this->t('No API key configured!');
      return SELF::SEVERITY_ERROR;
    }
    if (empty($this->config->get("zone"))) {
      $this->recommendation = $this->t('No Zone ID configured!');
      return SELF::SEVERITY_ERROR;
    }
    return SELF::SEVERITY_OK;
  }

}
